summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umllistview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/umllistview.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/umllistview.h')
-rw-r--r--umbrello/umbrello/umllistview.h59
1 files changed, 30 insertions, 29 deletions
diff --git a/umbrello/umbrello/umllistview.h b/umbrello/umbrello/umllistview.h
index ae9b3172..3420c1f4 100644
--- a/umbrello/umbrello/umllistview.h
+++ b/umbrello/umbrello/umllistview.h
@@ -43,15 +43,16 @@ class UMLClassifierListItem;
class UMLListView : public KListView {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs the tree view.
*
* @param parent The parent to this.
* @param name The internal name for this class.
*/
- UMLListView(TQWidget *parent,const char *name);
+ UMLListView(TQWidget *tqparent,const char *name);
/**
* Standard deconstructor.
@@ -87,7 +88,7 @@ public:
int getSelectedItems(UMLListViewItemList &ItemList);
/**
- * Get selected items, but only root elements selected (without children).
+ * Get selected items, but only root elements selected (without tqchildren).
*
* @param ItemList List of UMLListViewItems returned.
* @return The number of selected items.
@@ -105,41 +106,41 @@ public:
* CHECK - This is perhaps redundant since the
* UMLListViewItemData => UMLListViewItem merge.
* Creates a new UMLListViewItem from a UMLListViewItem, if
* parent is null the ListView Decides who is going to be the
* parent
*/
UMLListViewItem* createItem(UMLListViewItem& Data, IDChangeLog& IDChanges,
- UMLListViewItem* parent = 0);
+ UMLListViewItem* tqparent = 0);
/**
* Find the parent folder for a diagram.
* If the currently selected item in the list view is a folder
* then that folder is returned as the parent.
*
* @param dt The Diagram_Type of the diagram.
* The type will only be used if there is no currently
* selected item, or if the current item is not a folder.
* In that case the root folder which is suitable for the
* Diagram_Type is returned.
* @return Pointer to the parent UMLListViewItem for the diagram.
*/
UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
/**
* Determine the parent ListViewItem given an UMLObject.
*
* @param object Pointer to the UMLObject for which to look up the parent.
* @return Pointer to the parent UMLListViewItem chosen.
* Returns NULL on error (no parent could be determined.)
*/
UMLListViewItem* determineParentItem(UMLObject* object) const;
/**
* Determine the parent ListViewItem given a ListView_Type.
* This parent is used for creating new UMLListViewItems.
*
* @param lvt The ListView_Type for which to lookup the parent.
* @return Pointer to the parent UMLListViewItem chosen.
*/
UMLListViewItem* determineParentItem(Uml::ListView_Type lvt) const;
@@ -168,11 +169,11 @@ public:
}
/**
* Adds a new item to the tree of the given type under the given parent.
* Method will take care of signalling anyone needed on creation of new item.
* e.g. UMLDoc if an UMLObject is created.
*/
- void addNewItem(UMLListViewItem * parent, Uml::ListView_Type type);
+ void addNewItem(UMLListViewItem * tqparent, Uml::ListView_Type type);
/**
* Find an UMLObject in the listview.
@@ -259,7 +260,7 @@ public:
/**
* Moves an object given is unique ID and listview type to an
* other listview parent item.
* Also takes care of the corresponding move in the model.
*/
UMLListViewItem * moveObject(Uml::IDType srcId, Uml::ListView_Type srcType,
@@ -285,7 +286,7 @@ public:
* predefined root views (Root, Logical, UseCase, Component,
* Deployment, EntityRelationship.) Returns the ListView_Type
* of the matching root view; if no match then continues the
* search using the item's parent, then grandparent, and so forth.
* Returns Uml::lvt_Unknown if no match at all is found.
*/
Uml::ListView_Type rootViewType(UMLListViewItem *item);
@@ -294,7 +295,7 @@ public:
bool loadFromXMI( TQDomElement & element );
- bool loadChildrenFromXMI( UMLListViewItem * parent, TQDomElement & element );
+ bool loadChildrenFromXMI( UMLListViewItem * tqparent, TQDomElement & element );
protected:
UMLListViewItem* m_rv; // root view (home)
@@ -342,9 +343,9 @@ protected:
void loadPixmaps();
/**
* Deletes all child-items of @p parent.
*/
- void deleteChildrenOf( TQListViewItem *parent );
+ void deleteChildrenOf( TQListViewItem *tqparent );
/**
* Delete a listview item.
@@ -356,18 +357,18 @@ protected:
/**
* Adds a new operation, attribute or template item to a classifier, identical to
* childObjectAdded(obj) but with an explicit parent.
* @param child the child object
* @param parent the parent object
*/
- void childObjectAdded(UMLClassifierListItem* child, UMLClassifier* parent);
+ void childObjectAdded(UMLClassifierListItem* child, UMLClassifier* tqparent);
/**
* Auxiliary method for moveObject(): Adds the model object at the proper
* new container (package if nested, UMLDoc if at global level), and
* updates the containment relationships in the model.
*/
- void addAtContainer(UMLListViewItem *item, UMLListViewItem *parent);
+ void addAtContainer(UMLListViewItem *item, UMLListViewItem *tqparent);
public slots:
@@ -432,7 +433,7 @@ public slots:
/**
* Something has been dragged and dropped onto the list view
*/
- void slotDropped(TQDropEvent* de, TQListViewItem* parent, TQListViewItem* item);
+ void slotDropped(TQDropEvent* de, TQListViewItem* tqparent, TQListViewItem* item);
/**
* calls updateFolder() on the item to update the icon to open
@@ -43,15 +43,16 @@ class UMLClassifierListItem;
* Constructs the tree view.
*
- * @param parent The parent to this.
+ * @param tqparent The tqparent to this.
* @param name The internal name for this class.
*/
@@ -105,41 +106,41 @@ public:
* UMLListViewItemData => UMLListViewItem merge.
* Creates a new UMLListViewItem from a UMLListViewItem, if
- * parent is null the ListView Decides who is going to be the
- * parent
+ * tqparent is null the ListView Decides who is going to be the
+ * tqparent
*/
UMLListViewItem* createItem(UMLListViewItem& Data, IDChangeLog& IDChanges,
@@ -105,41 +106,41 @@ public:
/**
- * Find the parent folder for a diagram.
+ * Find the tqparent folder for a diagram.
* If the currently selected item in the list view is a folder
@@ -105,41 +106,41 @@ public:
* If the currently selected item in the list view is a folder
- * then that folder is returned as the parent.
+ * then that folder is returned as the tqparent.
*
* @param dt The Diagram_Type of the diagram.
@@ -105,41 +106,41 @@ public:
* In that case the root folder which is suitable for the
* Diagram_Type is returned.
- * @return Pointer to the parent UMLListViewItem for the diagram.
+ * @return Pointer to the tqparent UMLListViewItem for the diagram.
*/
UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
@@ -105,41 +106,41 @@ public:
UMLListViewItem *findFolderForDiagram(Uml::Diagram_Type dt);
/**
- * Determine the parent ListViewItem given an UMLObject.
+ * Determine the tqparent ListViewItem given an UMLObject.
*
@@ -105,41 +106,41 @@ public:
*
- * @param object Pointer to the UMLObject for which to look up the parent.
- * @return Pointer to the parent UMLListViewItem chosen.
- * Returns NULL on error (no parent could be determined.)
+ * @param object Pointer to the UMLObject for which to look up the tqparent.
+ * @return Pointer to the tqparent UMLListViewItem chosen.
+ * Returns NULL on error (no tqparent could be determined.)
*/
UMLListViewItem* determineParentItem(UMLObject* object) const;
@@ -105,41 +106,41 @@ public:
UMLListViewItem* determineParentItem(UMLObject* object) const;
/**
- * Determine the parent ListViewItem given a ListView_Type.
- * This parent is used for creating new UMLListViewItems.
+ * Determine the tqparent ListViewItem given a ListView_Type.
+ * This tqparent is used for creating new UMLListViewItems.
*
@@ -105,41 +106,41 @@ public:
*
- * @param lvt The ListView_Type for which to lookup the parent.
- * @return Pointer to the parent UMLListViewItem chosen.
+ * @param lvt The ListView_Type for which to lookup the tqparent.
+ * @return Pointer to the tqparent UMLListViewItem chosen.
*/
UMLListViewItem* determineParentItem(Uml::ListView_Type lvt) const;
@@ -168,11 +169,11 @@ public:
}
/**
- * Adds a new item to the tree of the given type under the given parent.
+ * Adds a new item to the tree of the given type under the given tqparent.
* Method will take care of signalling anyone needed on creation of new item.
* e.g. UMLDoc if an UMLObject is created.
@@ -259,7 +260,7 @@ public:
/**
* Moves an object given is unique ID and listview type to an
- * other listview parent item.
+ * other listview tqparent item.
* Also takes care of the corresponding move in the model.
*/
@@ -285,7 +286,7 @@ public:
* Deployment, EntityRelationship.) Returns the ListView_Type
* of the matching root view; if no match then continues the
- * search using the item's parent, then grandparent, and so forth.
+ * search using the item's tqparent, then grandtqparent, and so forth.
* Returns Uml::lvt_Unknown if no match at all is found.
*/
@@ -342,9 +343,9 @@ protected:
void loadPixmaps();
/**
- * Deletes all child-items of @p parent.
+ * Deletes all child-items of @p tqparent.
*/
@@ -356,18 +357,18 @@ protected:
/**
* Adds a new operation, attribute or template item to a classifier, identical to
- * childObjectAdded(obj) but with an explicit parent.
+ * childObjectAdded(obj) but with an explicit tqparent.
* @param child the child object
@@ -356,18 +357,18 @@ protected:
* @param child the child object
- * @param parent the parent object
+ * @param tqparent the tqparent object
*/